# Table of Contents

- [Table of Contents](#table-of-contents)
- [About](#about)
  - [Operating System Support](#operating-system-support)
  - [Python Version Support](#python-version-support)

# About

`ni.protobuf.types` is a Python package that provides Protobuf data types for NI gRPC APIs in
the [ni.protobuf.types package](https://github.com/ni/ni-apis/tree/main/ni/protobuf/types).
Additionally, this package contains methods for converting between Python and protobuf types.

NI created and supports this package.

## Operating System Support

`ni.protobuf.types` supports Windows and Linux operating systems.

## Python Version Support

`ni.protobuf.types` supports CPython 3.9+.

## Installation

You can directly install the `ni.protobuf.types` package using `pip` or by listing it as a
dependency in your project's `pyproject.toml` file.